@@ -65,7 +65,8 @@ static const XEVE_PARAM_METADATA xeve_params_metadata[] = {
     SET_XEVE_PARAM_METADATA( threads,                                   DT_INTEGER ),
     SET_XEVE_PARAM_METADATA( w,                                         DT_INTEGER ),
     SET_XEVE_PARAM_METADATA( h,                                         DT_INTEGER ),
-    SET_XEVE_PARAM_METADATA( fps,                                       DT_INTEGER ),
+    SET_XEVE_PARAM_METADATA( fps.num,                                   DT_INTEGER ),
+    SET_XEVE_PARAM_METADATA( fps.den,                                   DT_INTEGER),
     SET_XEVE_PARAM_METADATA( keyint,                                    DT_INTEGER ),
     SET_XEVE_PARAM_METADATA( cs,                                        DT_INTEGER ),
     SET_XEVE_PARAM_METADATA( rc_type,                                   DT_INTEGER ),
